maigesANOVA-class:
maigesANOVA class, extend maiges class to fit ANOVA models
Description
This class extends the class maiges adding two numerical
matrices to fit ANOVA models and estimate parameters of
interest. Additional to the existing slots of class
maiges this class defines other two, described in Slots section.
Slots
Dmatrix:- numeric matrix describing the design matrix
to fit an ANOVA model.
Cmatrix:- numeric matrix describing the contrasts
matrix to estimate parameters and contrasts of interest, after the
model fitting.
Methods
- [
signature(x = 'maigesANOVA'): sub-setting operator for
spots on the array or arrays in the batch, ensures that all slots
are subset properly. - boxplot
signature(x = 'maigesANOVA'): boxplot method for
maigesANOVA class. Display boxplots of the slides and
print tip groups using package marray or boxplots of
one gene previously defined. - dim
signature(x = 'maigesANOVA', value = 'numeric'): get
the dimensions of the object, numeric vector of length two. - image
signature(x = 'maigesANOVA'): image method for
maigesANOVA class. Display colour representation of
the slides using package marray. - plot
signature(x = 'maigesANOVA'): plot method for
maigesANOVA class. Display 'MA' plots. - print
signature(x = 'maigesANOVA'): print method for
maigesANOVA class. - show
signature(x = 'maigesANOVA'): show method for
maigesANOVA class. - summary
signature(x = 'maigesANOVA'): summary method for
maigesANOVA class.
Details
This class of objects is exactly the same as maiges with
the two slots described in Slots section. Objects of this class are generated from
maiges class using the function designANOVA. So,
it is possible to fit the model and estimate parameters or contrasts
using the function deGenesANOVA.