maigesDE-class:
maigesDE class, store results of differential gene expression
analysis
Description
This class defines a structure to store the results from differential
expression analysis. This type of analysis can be done using the
functions deGenes2by2Ttest,
deGenes2by2Wilcox and deGenes2by2BootT
for analysis between two biological sample types, or function
deGenesANOVA, for analysis between more than two sample
types using ANOVA models.
Slots
GeneInfo:- data frame containing the information
regarding the genes from the dataset.
SampleInfo:- data frame similar to the
GeneInfo
above, but containing information about the biological sample
types used in the analysis. fold:- numerical matrix containing the fold values
(mean difference between the sample types) when two sample types
were compared. Each matrix column gives one specific test.
stat:- numerical matrix giving the statistic of the
tests that were done. Each column represents on test.
p.value:- numerical matrix giving the p-values of the
statistical tests. Again, each column represents different tests.
factors:- character string giving the biological factors
used in ANOVA model (when ANOVA models were used).
test:- character string describing the test done.
Date:- character string giving date and time that the
object were created.
V.info:- list containg three characters. The first one is
a string containing the R version used when the object was
created. The second is a char vector with base packages and the
last one is another char vector with additional packages and
version numbers.
Methods
- plot
signature(x = 'maigesDE'): plot method for
maigesDE class. Display volcano plots. - print
signature(x = 'maigesDE'): print method for
maigesDE class. - show
signature(x = 'maigesDE'): show method for
maigesDE class. - summary
signature(x = 'maigesDE'): summary method for
maigesDE class.