maigesDEcluster-class:
maigesDEcluster class, store results of differential gene expression
analysis
Description
This class extends the class maigesDE to store results
from differential expression analysis. It is produced in the same way
as the latter, but has one more slot containing the W values. This is
useful to do cluster analysis. Together the slots of the
maigesDE class, it has one more given in Slots section.
Slots
W:- numeric matrix containing the W values for the
genes and samples used in the analysis.
Methods
- boxplot
signature(x = 'maigesDEcluster'): boxplot method for
maigesDEcluster class. Display boxplots of one gene
previously defined. - plot
signature(x = 'maigesDEcluster'): plot method for
maigesDEcluster class. Display MA plots. - print
signature(x = 'maigesDEcluster'): print method for
maigesDEcluster class. - show
signature(x = 'maigesDEcluster'): show method for
maigesDEcluster class. - summary
signature(x = 'maigesDEcluster'): summary method for
maigesDEcluster class.
Details
Objects of this class are produced in the same way as
maigesDE. The addition of the slot W turn
possible to do cluster analysis in this class of objects using the
functions hierMde, somMde and
kmeansMde, selecting genes according to the results of gene
expression analysis.